@@ -14,8 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from PySide import QtGui, QtCore
-from PySide.QtGui import QMessageBox
+from calculate.consolegui import qt
 import urllib2
 
 from DisplayMethod import DisplayMethod, StartWidget, ConnectLostLabel
@@ -44,9 +43,9 @@ def debug(level, *args):
             print s,
         print
 
-class MainWgt(QtGui.QMainWindow):
+class MainWgt(qt.QMainWindow):
     def __init__(self, ClientObj):
-        QtGui.QMainWindow.__init__(self)
+        qt.QMainWindow.__init__(self)
         self.ClientObj = ClientObj
         self.initUI()
 
@@ -54,17 +53,17 @@ class MainWgt(QtGui.QMainWindow):
         # Create bottom status bar
         #        self.statusbar = self.statusBar()
 
-        self.Main = QtGui.QWidget(self)
+        self.Main = qt.QWidget(self)
 
-        self.vlayout = QtGui.QVBoxLayout(self.Main)
+        self.vlayout = qt.QVBoxLayout(self.Main)
 
         # Create top main menu
         self.topmenu = MainMenu(self)
         self.vlayout.addWidget(self.topmenu)
 
-        self.layout_wgt = QtGui.QWidget(self)
-        self.layout = QtGui.QGridLayout(self.layout_wgt)
-        self.layout.setAlignment(QtCore.Qt.AlignLeft)
+        self.layout_wgt = qt.QWidget(self)
+        self.layout = qt.QGridLayout(self.layout_wgt)
+        self.layout.setAlignment(qt.Qt.AlignLeft)
 
         # add control button widget
         self.methodname_wgt = MethodNameWgt(self, self.ClientObj)
@@ -76,8 +75,8 @@ class MainWgt(QtGui.QMainWindow):
         self.left_frame.hide()
 
         # Main Frame
-        self.main_frame = QtGui.QScrollArea(self)
-        self.main_frame.setFrameShape(QtGui.QFrame.Shape.NoFrame)
+        self.main_frame = qt.QScrollArea(self)
+        self.main_frame.setFrameShape(qt.QFrame.NoFrame)
         self.main_frame.setObjectName('MF')
         #self.main_frame.setStyleSheet("#MF " "{background-color: #FFFFFF;}")
 
@@ -105,7 +104,7 @@ class MainWgt(QtGui.QMainWindow):
     def connecting(self):
         self.cur_size = self.size()
         self.ConnectWidget = FrameConnection(self, self.ClientObj)
-        self.ConnectWidget.setAttribute(QtCore.Qt.WA_ShowModal)
+        self.ConnectWidget.setWindowModality(qt.Qt.WindowModal)
         self.ConnectWidget.initUI(self, self.ClientObj._parent)
         self.ConnectWidget.show()
 
@@ -119,7 +118,7 @@ class MainWgt(QtGui.QMainWindow):
     # 3 methods for help menu
     def help(self):
         self.HelpWidget = HelpWgt(self)
-        self.HelpWidget.setAttribute(QtCore.Qt.WA_ShowModal)
+        self.HelpWidget.setWindowModality(qt.Qt.WindowModal)
         self.HelpWidget.show()
 
     def hand_book(self):
@@ -127,11 +126,11 @@ class MainWgt(QtGui.QMainWindow):
             site = "http://www.calculate-linux.ru/main/ru/calculate-console-gui"
         else:
             site = "http://www.calculate-linux.org/main/en/calculate-console-gui"
-        QtGui.QDesktopServices.openUrl(QtCore.QUrl(site))
+        qt.QDesktopServices.openUrl(qt.QUrl(site))
 
     def bug_report(self):
         self.bugWidget = BugWgt(self)
-        self.bugWidget.setAttribute(QtCore.Qt.WA_ShowModal)
+        self.bugWidget.setWindowModality(qt.Qt.WindowModal)
         self.bugWidget.show()
 
     def tools(self):
@@ -200,7 +199,7 @@ class MainWgt(QtGui.QMainWindow):
     def view_session_info(self):
         self.SessionWgt = ViewSessionInfo(self, self.ClientObj.client, \
                                           self.ClientObj._parent)
-        self.SessionWgt.setAttribute(QtCore.Qt.WA_ShowModal)
+        self.SessionWgt.setWindowModality(qt.Qt.WindowModal)
         self.SessionWgt.show()
 
     def disconnect(self, new_session=False):
@@ -208,22 +207,22 @@ class MainWgt(QtGui.QMainWindow):
             return 1
 
         if new_session:
-            reply = QtGui.QMessageBox.Yes
+            reply = qt.QMessageBox.Yes
         else:
             reply = self.show_close_messagebox()
 
-        if reply in [QtGui.QMessageBox.No, QtGui.QMessageBox.Yes]:
+        if reply in [qt.QMessageBox.No, qt.QMessageBox.Yes]:
             if hasattr(self.ClientObj, 'signaling'):
                 if self.ClientObj.signaling.isRunning():
                     self.ClientObj.signaling.close()
                     self.ClientObj.signaling.wait()
 
-        if reply == QtGui.QMessageBox.Yes:
+        if reply == qt.QMessageBox.Yes:
             # Exit with closing session
             client_del_sid(self.ClientObj.client)
             self.ClientObj.param_objects = {}
 
-        if reply in [QtGui.QMessageBox.No, QtGui.QMessageBox.Yes]:
+        if reply in [qt.QMessageBox.No, qt.QMessageBox.Yes]:
             if not self.topmenu.Processes.isEnabled():
                 self.topmenu.Processes.setEnabled(True)
                 self.topmenu.Session.setEnabled(True)
@@ -413,7 +412,7 @@ class MainWgt(QtGui.QMainWindow):
     def show_close_messagebox(self):
         list_pid = client_list_pid(self.ClientObj.client)
 
-        msgBox = QMessageBox(self)
+        msgBox = qt.QMessageBox(self)
         msgBox.setWindowTitle(_('Closing session'))
         msgBox.setText(_("Close this session") + ' ' + _('with %s?') \
                        % self.ClientObj.host_name + '\t')
@@ -427,16 +426,16 @@ class MainWgt(QtGui.QMainWindow):
                                             'data on process %d will be lost!') % len(
                     list_pid))
 
-        msgBox.setStandardButtons(QMessageBox.Yes | QMessageBox.No | \
-                                  QMessageBox.Cancel)
+        msgBox.setStandardButtons(qt.QMessageBox.Yes | qt.QMessageBox.No | \
+                                  qt.QMessageBox.Cancel)
 
         # translate
         msgBox.button(msgBox.Yes).setText(_('Yes'))
         msgBox.button(msgBox.No).setText(_('No'))
         msgBox.button(msgBox.Cancel).setText(_('Cancel'))
 
-        msgBox.setDefaultButton(QMessageBox.Cancel)
-        msgBox.setWindowIcon(QtGui.QIcon.fromTheme("application-exit"))
+        msgBox.setDefaultButton(qt.QMessageBox.Cancel)
+        msgBox.setWindowIcon(qt.QIcon.fromTheme("application-exit"))
         reply = msgBox.exec_()
         return reply
 
@@ -444,7 +443,7 @@ class MainWgt(QtGui.QMainWindow):
         if self.ClientObj.client:
             reply = self.show_close_messagebox()
 
-            if reply == QtGui.QMessageBox.Yes or reply == QtGui.QMessageBox.No:
+            if reply == qt.QMessageBox.Yes or reply == qt.QMessageBox.No:
                 self.topmenu.Processes.setEnabled(True)
                 self.topmenu.Session.setEnabled(True)
                 self.topmenu.Back.setEnabled(True)
@@ -462,7 +461,7 @@ class MainWgt(QtGui.QMainWindow):
                             ['127.0.0.1', 'localhost']:
                         self.ClientObj._parent.set_localhost(None)
 
-                if reply == QtGui.QMessageBox.Yes:
+                if reply == qt.QMessageBox.Yes:
                     # Closing session
                     client_del_sid(self.ClientObj.client)
                 return 1
@@ -472,7 +471,7 @@ class MainWgt(QtGui.QMainWindow):
             return 1
 
     def keyPressEvent(self, e):
-        if e.key() == QtCore.Qt.Key_Return:
+        if e.key() == qt.Qt.Key_Return:
             self.control_button.keyPressEvent(e)
         else:
-            QtGui.QMainWindow.keyPressEvent(self, e)
+            qt.QMainWindow.keyPressEvent(self, e)
