@@ -18,7 +18,7 @@ import dbus
 import dbus.service
 import dbus.mainloop.glib
 
-from PySide import QtGui, QtCore
+from calculate.consolegui import qt
 import sudsds, time, sys
 import os, pwd, shutil
 import ConfigParser
@@ -32,9 +32,9 @@ from pid_information import client_pid_info
 #from calculate.lib.cl_lang import setLocalTranslate
 #setLocalTranslate('console_gui',sys.modules[__name__])
 
-class SelectedMethodWgt(QtGui.QWidget):
+class SelectedMethodWgt(qt.QWidget):
     def __init__(self, app, args):
-        QtGui.QWidget.__init__(self)
+        qt.QWidget.__init__(self)
         self.args = args
         self.user_changed_flag = False
         self.lang = args.lang
@@ -50,18 +50,18 @@ class SelectedMethodWgt(QtGui.QWidget):
         self.port = args.port or self.VarsGui.GetInteger('core.cl_core_port')
         self.MethodWidget = self.ClientObj.MainWidget
         self.MethodWidget.topmenu.hide()
-        layout = QtGui.QHBoxLayout(self)
+        layout = qt.QHBoxLayout(self)
         layout.setContentsMargins(0,0,0,0)
         layout.setSpacing(0)
         layout.addWidget(self.MethodWidget)
 
-        QtGui.QIcon.setThemeName('Calculate')
-        icon = QtGui.QIcon.fromTheme('cl-console-gui-%s'%self.method.replace("_","-"))
+        qt.QIcon.setThemeName('Calculate')
+        icon = qt.QIcon.fromTheme('cl-console-gui-%s'%self.method.replace("_","-"))
         if icon.isNull():
-            icon = QtGui.QIcon.fromTheme('calculate-%s'%self.method.replace("_","-"))
+            icon = qt.QIcon.fromTheme('calculate-%s'%self.method.replace("_","-"))
 
         self.setWindowIcon(icon)
-        QtGui.QApplication.setWindowIcon(icon)
+        qt.QApplication.setWindowIcon(icon)
 
         conf_path = self.VarsGui.Get('cl_gui_config_path')
         homePath = self.VarsGui.Get('ur_home_path')
@@ -134,8 +134,9 @@ class SelectedMethodWgt(QtGui.QWidget):
         self.config = ConfigParser.ConfigParser()
         self.config.read(self.user_config)
         try:
-            self.config.set('gui', 'size', ','.join(map(lambda x: str(x),
-                                                    self.size().toTuple())))
+            selfsize = self.size()
+            self.config.set('gui', 'size',
+                "{},{}".format(selfsize.width(), selfsize.height()))
             self.config.write(open(self.user_config, 'w'))
         except (ConfigParser.NoOptionError, ConfigParser.NoSectionError):
             return False
@@ -160,12 +161,12 @@ class SelectedMethodWgt(QtGui.QWidget):
                 self.ClientObj.signaling.wait()
             return 1
         if not self.user_changed_flag:
-            reply = QtGui.QMessageBox.Yes
+            reply = qt.QMessageBox.Yes
         else:
             reply = self.show_close_messagebox()
 
         from mainframe import MainFrame
-        if reply == QtGui.QMessageBox.Yes:
+        if reply == qt.QMessageBox.Yes:
             if hasattr (self, 'con_lost_lbl'):
                 self.con_lost_lbl.hide()
                 self.con_lost_lbl.close()
@@ -188,31 +189,31 @@ class SelectedMethodWgt(QtGui.QWidget):
                     if self.ClientObj.process_dict[str(pid)]['status'] != '1':
                         return 1
                     time.sleep(1)
-        elif reply == QtGui.QMessageBox.No:
+        elif reply == qt.QMessageBox.No:
             return 0
 
     def user_changed(self):
         self.user_changed_flag = True
 
     def show_close_messagebox(self):
-        msgBox = QtGui.QMessageBox(self)
+        msgBox = qt.QMessageBox(self)
         if self.ClientObj.method_names.has_key(self.method):
             method_name = self.ClientObj.method_names[self.method]
         else:
             method_name = self.method
         msgBox.setText(_("Close") +' "%s"?' %method_name)
 
-        msgBox.setStandardButtons(QtGui.QMessageBox.Yes | QtGui.QMessageBox.No)
+        msgBox.setStandardButtons(qt.QMessageBox.Yes | qt.QMessageBox.No)
 
         # translate
         msgBox.button(msgBox.Yes).setText(_('Yes'))
         msgBox.button(msgBox.No).setText(_('No'))
-        if QtGui.QIcon.hasThemeIcon('dialog-close'):
+        if qt.QIcon.hasThemeIcon('dialog-close'):
             msgBox.button(msgBox.No).setIcon \
-                                    (QtGui.QIcon.fromTheme('dialog-close'))
+                                    (qt.QIcon.fromTheme('dialog-close'))
 
-        msgBox.setDefaultButton(QtGui.QMessageBox.No)
-        msgBox.setWindowIcon(QtGui.QIcon.fromTheme("application-exit"))
+        msgBox.setDefaultButton(qt.QMessageBox.No)
+        msgBox.setWindowIcon(qt.QIcon.fromTheme("application-exit"))
         reply = msgBox.exec_()
         return reply
 
@@ -252,29 +253,30 @@ def parse():
     return parser
 
 
-class MyTabBar(QtGui.QTabBar):
+class MyTabBar(qt.QTabBar):
     def __init__(self, _parent):
-        QtGui.QTabBar.__init__(self)
+        qt.QTabBar.__init__(self)
         self._parent = _parent
 
     def wheelEvent(self, event):
         event.ignore()
 
     def mousePressEvent(self, event):
-        if event.button() == QtCore.Qt.MouseButton.LeftButton:
+        if event.button() == qt.Qt.LeftButton:
             self.setCurrentIndex(self.tabAt(event.pos()))
             event.accept()
-        if event.button() == QtCore.Qt.MouseButton.MiddleButton:
+        if event.button() == qt.Qt.MiddleButton:
             self._parent.close_tab(self.tabAt(event.pos()))
 
-class ToolTabWidget(QtGui.QTabWidget):
+class ToolTabWidget(qt.QTabWidget):
     def __init__(self, app, args = None, host = None, port = None):
-        QtGui.QTabWidget.__init__(self)
+        qt.QTabWidget.__init__(self)
         self.app = app
         if args:
             if args.lang:
                 self.lang = args.lang
 
+        self.current_icon = None
         self.setContentsMargins(0,0,0,0)
         self.init_variables()
 
@@ -286,17 +288,17 @@ class ToolTabWidget(QtGui.QTabWidget):
         ClientObj = ApiClient(app, self)
         self.FirstWidget = ClientObj.MainWidget
 
-        self.PlusWidget = QtGui.QWidget(self)
+        self.PlusWidget = qt.QWidget(self)
 
         self.tabbar = MyTabBar(self)
         self.setTabBar(self.tabbar)
 
-        QtGui.QIcon.setThemeName('Calculate')
-        self.gui_icon = QtGui.QIcon.fromTheme("video-display")
+        qt.QIcon.setThemeName('Calculate')
+        self.gui_icon = qt.QIcon.fromTheme("video-display")
 
-        self.other_icon = QtGui.QIcon.fromTheme("list-add")
+        self.other_icon = qt.QIcon.fromTheme("list-add")
         if self.other_icon.isNull():
-            self.other_icon = QtGui.QIcon.fromTheme("preferences-desctop")
+            self.other_icon = qt.QIcon.fromTheme("preferences-desctop")
 
         self.addTab(self.FirstWidget, self.gui_icon , self.new_con_txt)
         self.addTab(self.PlusWidget, self.other_icon, '')
@@ -308,7 +310,7 @@ class ToolTabWidget(QtGui.QTabWidget):
         self.currentChanged.connect(self.changeWindowTitle)
 
         self.setTabsClosable(True)
-        self.tabbar.tabButton(1, QtGui.QTabBar.ButtonPosition.RightSide).hide()
+        self.tabbar.tabButton(1, qt.QTabBar.RightSide).hide()
 
         if not self.get_size():
             # definition of screen resolution
@@ -339,9 +341,8 @@ class ToolTabWidget(QtGui.QTabWidget):
                             stop: 0 #E9E9E9, stop: 0.4 #E5E5E5,
                             stop: 0.5 #E1E1E1, stop: 1.0 #DDDDDD);}
                             ''')
-        self.setWindowIcon(QtGui.QIcon \
-                          ('/usr/share/pixmaps/calculate-console-offline.svg'))
 
+        self.set_offline_icon()
         self.show()
         self.app.processEvents()
 
@@ -366,6 +367,18 @@ class ToolTabWidget(QtGui.QTabWidget):
         if self.FirstWidget.ClientObj.client:
             self.tray.set_icon(True)
 
+    def set_offline_icon(self):
+        if self.current_icon != "offline":
+            self.current_icon = "offline"
+            self.setWindowIcon(qt.QIcon \
+                        ('/usr/share/pixmaps/calculate-console-offline.svg'))
+
+    def set_online_icon(self):
+        if self.current_icon != "online":
+            self.current_icon = "online"
+            self.setWindowIcon(qt.QIcon \
+                        ('/usr/share/pixmaps/calculate-console-online.svg'))
+
     def connect_count_changed(self, host, port, count):
         if count:
             if not host in self.connect_dict:
@@ -382,13 +395,11 @@ class ToolTabWidget(QtGui.QTabWidget):
                     self.connect_dict.pop(host)
 
         if self.connect_dict:
-            self.setWindowIcon(QtGui.QIcon \
-                        ('/usr/share/pixmaps/calculate-console-online.svg'))
+            self.set_online_icon()
             if hasattr(self, 'tray'):
                 self.tray.set_icon(True)
         else:
-            self.setWindowIcon(QtGui.QIcon \
-                         ('/usr/share/pixmaps/calculate-console-offline.svg'))
+            self.set_offline_icon()
             if hasattr(self, 'tray'):
                 self.tray.set_icon(False)
 
@@ -496,7 +507,7 @@ class ToolTabWidget(QtGui.QTabWidget):
 #            self.connect_dict[ClientObj.host_name] = \
 #                             [ClientObj, self.currentIndex()]
 #        self.tabbar.tabButton(self.currentIndex(), \
-#                              QtGui.QTabBar.ButtonPosition.RightSide).hide()
+#                              qt.QTabBar.RightSide).hide()
 
     def find_host(self, host_name, port):
         ind = self.currentIndex()
@@ -551,14 +562,15 @@ class ToolTabWidget(QtGui.QTabWidget):
         self.config = ConfigParser.ConfigParser()
         self.config.read(self.user_config)
         try:
-            self.config.set('gui', 'size', ','.join(map(lambda x: str(x),
-                                                    self.size().toTuple())))
+            selfsize = self.size()
+            self.config.set('gui', 'size',
+                "{},{}".format(selfsize.width(), selfsize.height()))
             self.config.write(open(self.user_config, 'w'))
         except (ConfigParser.NoOptionError, ConfigParser.NoSectionError):
             return False
 
     def keyPressEvent(self, e):
-        if e.key() == QtCore.Qt.Key_Return:
+        if e.key() == qt.Qt.Key_Return:
             self.currentWidget().keyPressEvent(e)
         else:
-            QtGui.QTabWidget.keyPressEvent(self, e)
+            qt.QTabWidget.keyPressEvent(self, e)
