@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from PySide import QtGui, QtCore
+from calculate.consolegui import qt
 from sudsds import WebFault
 import logging, OpenSSL
 import ConfigParser, os, urllib2
@@ -27,34 +27,34 @@ from calculate.core.client.cert_verify import VerifyError
 from client_class import Client_suds, HTTPSClientCertTransport
 from more import post_connect_action, show_msg, uniq, LabelWordWrap
 
-class LocalhostPasswd(QtGui.QDialog):
+class LocalhostPasswd(qt.QDialog):
     def __init__(self, parent):
-        QtGui.QDialog.__init__(self)
-        grid = QtGui.QGridLayout(self)
+        qt.QDialog.__init__(self)
+        grid = qt.QGridLayout(self)
         grid.setContentsMargins(10, 10, 10, 10)
         grid.setSpacing(4)
-        self.lbl_passwd = QtGui.QLabel(_("Password"), self)
-        self.text_passwd = QtGui.QLineEdit('', self)
+        self.lbl_passwd = qt.QLabel(_("Password"), self)
+        self.text_passwd = qt.QLineEdit('', self)
         self.text_passwd.setEchoMode(self.text_passwd.Password)
         grid.addWidget(self.lbl_passwd, 0, 0)
         grid.addWidget(self.text_passwd, 0, 1)
 
-        layout_button = QtGui.QHBoxLayout()
-        self.cmd_ok = QtGui.QPushButton(_('Ok'), self)
+        layout_button = qt.QHBoxLayout()
+        self.cmd_ok = qt.QPushButton(_('Ok'), self)
         self.cmd_ok.setDefault(True)
         self.cmd_ok.setAutoDefault(True)
         self.cmd_ok.clicked.connect(self.set_disabled)
         self.cmd_ok.clicked.connect(self.onClick)
         self.cmd_ok.setFixedWidth(100)
 
-        self.cmd_cancel = QtGui.QPushButton(_('Cancel'), self)
-        self.cmd_cancel.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Escape))
+        self.cmd_cancel = qt.QPushButton(_('Cancel'), self)
+        self.cmd_cancel.setShortcut(qt.QKeySequence(qt.Qt.Key_Escape))
         self.cmd_cancel.clicked.connect(self.close)
         self.cmd_cancel.setFixedWidth(100)
         layout_button.addWidget(self.cmd_ok)
         layout_button.addWidget(self.cmd_cancel)
 
-        grid.addLayout(layout_button, 1,0,1,2, QtCore.Qt.AlignRight)
+        grid.addLayout(layout_button, 1,0,1,2, qt.Qt.AlignRight)
         self.setLayout(grid)
         self.setFixedSize(self.sizeHint())
         self._text = None
@@ -70,22 +70,22 @@ class LocalhostPasswd(QtGui.QDialog):
     def text(self):
         return self._text
 
-class FrameConnection(QtGui.QWidget):
+class FrameConnection(qt.QWidget):
     def __init__(self, parent, ClientObj):
-        QtGui.QWidget.__init__(self)
+        qt.QWidget.__init__(self)
         self.ClientObj = ClientObj
 
     def initUI(self, parent, window):
-        grid = QtGui.QGridLayout(self)
+        grid = qt.QGridLayout(self)
         grid.setContentsMargins(10, 10, 10, 10)
         grid.setSpacing(4)
 
         self.lbl_host = LabelWordWrap(_("Host"), self)
         self.lbl_port = LabelWordWrap(_("Port"), self)
         self.lbl_passwd = LabelWordWrap(_("Password"), self)
-        self.text_host = QtGui.QLineEdit(self.ClientObj.default_host, self)
-        self.text_port = QtGui.QLineEdit(self.ClientObj.default_port, self)
-        self.text_passwd = QtGui.QLineEdit('', self)
+        self.text_host = qt.QLineEdit(self.ClientObj.default_host, self)
+        self.text_port = qt.QLineEdit(self.ClientObj.default_port, self)
+        self.text_passwd = qt.QLineEdit('', self)
         self.text_passwd.setEchoMode(self.text_passwd.Password)
         ######################
         # add completer in 'host name' QLineEdit 
@@ -94,8 +94,8 @@ class FrameConnection(QtGui.QWidget):
                 self.wordList.append (self.text_host.text())
                 self.wordList = uniq(self.wordList)
                 del (self.completer)
-                self.completer = QtGui.QCompleter(self.wordList, self)
-                self.completer.setCaseSensitivity(QtCore.Qt.CaseInsensitive)
+                self.completer = qt.QCompleter(self.wordList, self)
+                self.completer.setCaseSensitivity(qt.Qt.CaseInsensitive)
                 self.completer.setMaxVisibleItems(7)
                 self.text_host.setCompleter(self.completer)
             return wrapper
@@ -109,8 +109,8 @@ class FrameConnection(QtGui.QWidget):
         except (ConfigParser.NoOptionError, ConfigParser.NoSectionError):
             self.wordList = []
 
-        self.completer = QtGui.QCompleter(self.wordList, self)
-        self.completer.setCaseSensitivity(QtCore.Qt.CaseInsensitive)
+        self.completer = qt.QCompleter(self.wordList, self)
+        self.completer.setCaseSensitivity(qt.Qt.CaseInsensitive)
         self.completer.setMaxVisibleItems(7)
         self.text_host.setCompleter(self.completer)
         self.text_host.editingFinished.connect(add_wordlist(self))
@@ -122,20 +122,20 @@ class FrameConnection(QtGui.QWidget):
         grid.addWidget(self.lbl_passwd, 2, 0)
         grid.addWidget(self.text_passwd, 2, 1)
 
-        self.cmd_connect = QtGui.QPushButton(_('Connect'), self)
-        self.cmd_connect.setIcon(QtGui.QIcon.fromTheme("network-connect"))
+        self.cmd_connect = qt.QPushButton(_('Connect'), self)
+        self.cmd_connect.setIcon(qt.QIcon.fromTheme("network-connect"))
         self.cmd_connect.setDefault(True)
         self.cmd_connect.setAutoDefault(True)
 #        self.cmd_connect.setMaximumWidth(120)
-        self.cmd_connect.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Return))
+        self.cmd_connect.setShortcut(qt.QKeySequence(qt.Qt.Key_Return))
 
-        self.cmd_cancel = QtGui.QPushButton(_('Cancel'), self)
+        self.cmd_cancel = qt.QPushButton(_('Cancel'), self)
 
 #        self.cmd_cancel.setMaximumWidth(120)
-        self.cmd_cancel.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Escape))
+        self.cmd_cancel.setShortcut(qt.QKeySequence(qt.Qt.Key_Escape))
         self.cmd_cancel.clicked.connect(self.close)
 
-        layout_button = QtGui.QHBoxLayout()
+        layout_button = qt.QHBoxLayout()
         layout_button.addWidget(self.cmd_connect)
         layout_button.addWidget(self.cmd_cancel)
         grid.addLayout(layout_button, 3, 0, 1, 2)
@@ -144,11 +144,10 @@ class FrameConnection(QtGui.QWidget):
         grid.setColumnStretch(1,5)
 
         self.cmd_connect.clicked.connect (self.set_disabled)
-        self.cmd_connect.connect \
-            (self.cmd_connect, QtCore.SIGNAL('clicked()'), self.onClick)
+        self.cmd_connect.clicked.connect (self.onClick)
         
         # for clear memory after closed this window
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setAttribute(qt.Qt.WA_DeleteOnClose)
         
         self.setLayout(grid)
         
@@ -158,7 +157,7 @@ class FrameConnection(QtGui.QWidget):
                   window.geometry().y() + window.geometry().height() / 2 \
                   - self.sizeHint().height() / 2)
         self.setWindowTitle(_('Connection'))
-        self.setWindowIcon(QtGui.QIcon.fromTheme("network-connect"))
+        self.setWindowIcon(qt.QIcon.fromTheme("network-connect"))
         
     def set_disabled(self):
 
@@ -167,6 +166,7 @@ class FrameConnection(QtGui.QWidget):
         
     # establish a connection
     def onClick(self):
+        print "DEBUG: onClick"
         self.setDisabled(True)
         if self.ClientObj.client:
             show_msg(_('You are connected to the server!')+'\n' + \
