@@ -16,29 +16,28 @@
 
 import os
 
-from PySide import QtGui, QtCore
-from PySide.QtGui import QComboBox
+from calculate.consolegui import qt
 
 from more import LabelWordWrap, FileOpenWgt, show_msg, show_question, \
                  client_list_methods
 
-class ToolsWidget (QtGui.QWidget):
+class ToolsWidget (qt.QWidget):
     def __init__(self, parent, ClientObj, window):
-        QtGui.QWidget.__init__(self)
-        self.vlayout = QtGui.QVBoxLayout(self)
-        self.vlayout.setAlignment(QtCore.Qt.AlignTop)
-        self.vlayout.setAlignment(QtCore.Qt.AlignRight)
+        qt.QWidget.__init__(self)
+        self.vlayout = qt.QVBoxLayout(self)
+        self.vlayout.setAlignment(qt.Qt.AlignTop)
+        self.vlayout.setAlignment(qt.Qt.AlignRight)
 
 #        self.move(100+parent.frameGeometry().x(), \
 #                          100+parent.frameGeometry().y())
 
         self.setFixedSize(450, 220)
-        self.setWindowTitle(_('Tools'))
+        self.setWindowTitle(_('Preferences'))
 
-        self.setWindowIcon(QtGui.QIcon.fromTheme("preferences-other"))
+        self.setWindowIcon(qt.QIcon.fromTheme("preferences-other"))
         # for clear memory after closed this window
-        self.setAttribute(QtCore.Qt.WA_ShowModal)
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setWindowModality(qt.Qt.WindowModal)
+        self.setAttribute(qt.Qt.WA_DeleteOnClose)
 
         self.create(parent, ClientObj)
 
@@ -46,8 +45,8 @@ class ToolsWidget (QtGui.QWidget):
                   - self.size().width() / 2, \
                   window.geometry().y() + window.geometry().height() / 2 \
                   - self.size().height() / 2)
-    gui_signal = QtCore.Signal()
-    other_signal = QtCore.Signal()
+    gui_signal = qt.Signal()
+    other_signal = qt.Signal()
 
     def create(self, parent, ClientObj):
         if self.layout():
@@ -58,8 +57,8 @@ class ToolsWidget (QtGui.QWidget):
                 del (child)            
 
         # Add clear config button
-        clear_icon = QtGui.QIcon.fromTheme("edit-delete-page")
-        clear_button = QtGui.QPushButton (clear_icon,
+        clear_icon = qt.QIcon.fromTheme("edit-delete-page")
+        clear_button = qt.QPushButton (clear_icon,
                                     _('Clear the configuration file'),self)
         clear_button.clicked.connect(self.clear_config(parent, ClientObj))
 
@@ -70,27 +69,27 @@ class ToolsWidget (QtGui.QWidget):
         self.vlayout.addWidget(tab)
 
         # add ok, apply and cancel button
-        botton_wgt = QtGui.QWidget(self)
-        self.botton_layout = QtGui.QHBoxLayout(botton_wgt)
+        botton_wgt = qt.QWidget(self)
+        self.botton_layout = qt.QHBoxLayout(botton_wgt)
         self.botton_layout.setContentsMargins(0,0,0,0)
-        self.botton_layout.setAlignment(QtCore.Qt.AlignRight)
+        self.botton_layout.setAlignment(qt.Qt.AlignRight)
 
-        toolOk = QtGui.QPushButton(_('Ok'), self)
+        toolOk = qt.QPushButton(_('Ok'), self)
         toolOk.setFixedWidth(50)
-        toolOk.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Return))
+        toolOk.setShortcut(qt.QKeySequence(qt.Qt.Key_Return))
         toolOk.clicked.connect(self.save_changes(ClientObj, tab))
         toolOk.clicked.connect(self.close)
         self.botton_layout.addWidget(toolOk)
 
-        toolApply = QtGui.QPushButton(_('Apply'), self)
+        toolApply = qt.QPushButton(_('Apply'), self)
         toolApply.setFixedWidth(100)
         toolApply.clicked.connect(self.save_changes(ClientObj, tab))
         self.botton_layout.addWidget(toolApply)
 
-        toolQuit = QtGui.QPushButton(_('Cancel'), self)
+        toolQuit = qt.QPushButton(_('Cancel'), self)
         toolQuit.setFixedWidth(100)
         toolQuit.clicked.connect(self.close)
-        toolQuit.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Escape))
+        toolQuit.setShortcut(qt.QKeySequence(qt.Qt.Key_Escape))
         self.botton_layout.addWidget(toolQuit)
 
         self.gui_signal.connect(tab.GuiWidget.save_changes(ClientObj))
@@ -124,37 +123,37 @@ class ToolsWidget (QtGui.QWidget):
                 self.create(parent, ClientObj)
         return wrapper
 
-class ToolTabWidget(QtGui.QTabWidget):
+class ToolTabWidget(qt.QTabWidget):
     def __init__(self, parent, ClientObj):
-        QtGui.QTabWidget.__init__(self, parent)
+        qt.QTabWidget.__init__(self, parent)
         self.ClientObj = ClientObj
 
         self.GuiWidget = ToolGui(self, ClientObj)
 
         self.OtherWidget = ToolOther(self, ClientObj)
 
-        self.gui_icon = QtGui.QIcon.fromTheme("video-display")
+        self.gui_icon = qt.QIcon.fromTheme("video-display")
 
-        self.other_icon = QtGui.QIcon.fromTheme("preferences-other")
+        self.other_icon = qt.QIcon.fromTheme("preferences-other")
         if self.other_icon.isNull():
-            self.other_icon = QtGui.QIcon.fromTheme("preferences-desctop")
+            self.other_icon = qt.QIcon.fromTheme("preferences-desctop")
 
-        self.addTab(self.GuiWidget, self.gui_icon ,_('GUI Tools'))
-        self.addTab(self.OtherWidget, self.other_icon, _('Other Tools'))
+        self.addTab(self.GuiWidget, self.gui_icon ,_('GUI'))
+        self.addTab(self.OtherWidget, self.other_icon, _('Other'))
 
         # message about save
         self.cur_tab_num = 0
         self.changed_flag = False
         self.currentChanged.connect(self.save_mess)
 
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setAttribute(qt.Qt.WA_DeleteOnClose)
 
-    gui_signal = QtCore.Signal()
-    other_signal = QtCore.Signal()
+    gui_signal = qt.Signal()
+    other_signal = qt.Signal()
 
     def save_mess(self, tab_num):
         # change tab with unsaved changes
-        tab_list = [_('GUI Tools'),_('Other Tools')]
+        tab_list = [_('GUI'),_('Other')]
 
         if self.changed_flag:
             text = _('There are unsaved changes in tab %s') \
@@ -164,7 +163,7 @@ class ToolTabWidget(QtGui.QTabWidget):
             reply = show_question(self.parent(), text, informative_text,
                                   title = _('Saving changes'))
 
-            if reply == QtGui.QMessageBox.Yes:
+            if reply == qt.QMessageBox.Yes:
                 if self.cur_tab_num == 0:
                     self.gui_signal.connect \
                                   (self.GuiWidget.save_changes(self.ClientObj))
@@ -180,35 +179,35 @@ class ToolTabWidget(QtGui.QTabWidget):
             if self.cur_tab_num == 0:
                 self.GuiWidget = ToolGui(self, self.ClientObj)
                 self.insertTab(self.cur_tab_num, self.GuiWidget, \
-                                            self.gui_icon, _('GUI Tools'))
+                                            self.gui_icon, _('GUI'))
             elif self.cur_tab_num == 1:
                 self.OtherWidget = ToolOther(self, self.ClientObj)
                 self.insertTab(self.cur_tab_num, self.OtherWidget, \
-                                        self.other_icon, _('Other Tools'))
+                                        self.other_icon, _('Other'))
 
         self.cur_tab_num = tab_num
         self.changed_flag = False
 
 # Gui tools in ToolTabWidget
-class ToolGui(QtGui.QWidget):
+class ToolGui(qt.QWidget):
     def __init__(self, parent, ClientObj):
-        QtGui.QWidget.__init__(self, parent)
+        qt.QWidget.__init__(self, parent)
         self.user_config = ClientObj.user_config
         self._parent = parent
 
-        self.grid = QtGui.QGridLayout(self)
+        self.grid = qt.QGridLayout(self)
 
         self.grid.setContentsMargins(2,2,2,2)
         self.grid.setSpacing(2)
         self.grid.setColumnStretch(0,3)
         self.grid.setColumnStretch(1,5)
-#        self.grid.setAlignment(QtCore.Qt.AlignLeft)
+#        self.grid.setAlignment(qt.Qt.AlignLeft)
 
         # add height image in grid
         self.h_image_lbl = LabelWordWrap(_('Image height'), self)
         self.h_image_lbl.setMaximumWidth(self.h_image_lbl.sizeHint().width())
 
-        self.h_image_lineedit = QtGui.QLineEdit(self)
+        self.h_image_lineedit = qt.QLineEdit(self)
         self.h_image_lineedit.setToolTip(_('Set a fixed height image for '
                                          'actions')+' '+_('0: hide images'))
 
@@ -222,7 +221,7 @@ class ToolGui(QtGui.QWidget):
         self.count_row_lbl.setMaximumWidth \
                                     (self.count_row_lbl.sizeHint().width())
 
-        self.count_row_lineedit = QtGui.QLineEdit(self)
+        self.count_row_lineedit = qt.QLineEdit(self)
 
         self.count_row_lineedit.setText(str(ClientObj.count_row_res_table))
 
@@ -230,8 +229,8 @@ class ToolGui(QtGui.QWidget):
         self.grid.addWidget(self.count_row_lineedit, 2, 1)
 
         # add spacer
-        self.grid.addItem(QtGui.QSpacerItem(0,0, QtGui.QSizePolicy.Expanding, \
-                          QtGui.QSizePolicy.Expanding ), 3, 0, 1, 2)
+        self.grid.addItem(qt.QSpacerItem(0,0, qt.QSizePolicy.Expanding, \
+                          qt.QSizePolicy.Expanding ), 3, 0, 1, 2)
 
         # connect all with change value slot
         self.h_image_lineedit.textChanged.connect(self.changed_val)
@@ -333,13 +332,13 @@ class ToolGui(QtGui.QWidget):
         return wrapper
 
 # Other tools in ToolTabWidget
-class ToolOther(QtGui.QWidget):
+class ToolOther(qt.QWidget):
     def __init__(self, parent, ClientObj):
-        QtGui.QWidget.__init__(self, parent)
+        qt.QWidget.__init__(self, parent)
         self.user_config = ClientObj.user_config
         self._parent = parent
 
-        self.grid = QtGui.QGridLayout(self)
+        self.grid = qt.QGridLayout(self)
 
         self.grid.setContentsMargins(2,2,2,2)
         self.grid.setSpacing(2)
@@ -350,7 +349,7 @@ class ToolOther(QtGui.QWidget):
         self.lang_lbl = LabelWordWrap(_('Select Language'), self)
         self.lang_lbl.setMaximumWidth(self.lang_lbl.sizeHint().width())
 
-        self.lang_ComboBox = QComboBox(self)
+        self.lang_ComboBox = qt.QComboBox(self)
         lang_dict = {'en': _('English'),'ru': _('Russian'),'fr':_('French'),
             'uk':_('Ukrainian')}
 
@@ -383,7 +382,7 @@ class ToolOther(QtGui.QWidget):
 #        self.timeout_lbl = LabelWordWrap(_('Timeout'), self)
 #        self.timeout_lbl.setMaximumWidth(self.timeout_lbl.sizeHint().width())
 #
-#        self.timeout_lineedit = QtGui.QLineEdit(self)
+#        self.timeout_lineedit = qt.QLineEdit(self)
 #
 #        self.timeout_lineedit.setText(str(ClientObj.timeout))
 #
@@ -391,15 +390,15 @@ class ToolOther(QtGui.QWidget):
 #        self.grid.addWidget(self.timeout_lineedit, 2, 1)
 
         # add spacer
-        self.grid.addItem(QtGui.QSpacerItem(0,0, QtGui.QSizePolicy.Expanding, \
-                                QtGui.QSizePolicy.Expanding ), 5, 0, 1, 2)
+        self.grid.addItem(qt.QSpacerItem(0,0, qt.QSizePolicy.Expanding, \
+                                qt.QSizePolicy.Expanding ), 5, 0, 1, 2)
 
         # connect all with change value slot
         self.lang_ComboBox.currentIndexChanged.connect(self.changed_val)
         self.fd_cert.textChanged.connect(self.changed_val)
 #        self.timeout_lineedit.editTextChanged.connect(self.changed_val)
 
-        self.setAttribute(QtCore.Qt.WA_DeleteOnClose)
+        self.setAttribute(qt.Qt.WA_DeleteOnClose)
 
     def changed_val(self):
         self._parent.changed_flag = True
